@@ -639,6 +639,8 @@ class BacSeg(QWidget):
                 worker.signals.result.connect(partial(self.process_cell_statistics, path=path))
                 self.threadpool.start(worker)
 
+
+
     def update_import_limit(self):
 
         if self.import_filemode.currentIndex() == 0:
@@ -736,7 +738,7 @@ class BacSeg(QWidget):
 
         shift_image = False
         if active_layer != None:
-            if active_layer.name not in ["Segmentations","Classes"]:
+            if active_layer.name not in ["Segmentations","Classes","center_lines"]:
                 shift_image = True
 
         if shift_image is True:
